use std::path::Path;

use crate::parsed_config_processing::*;

use super::*;

pub fn gen_compile_commands(
    name: &str,
    target: &Target,
    config: &ConfigTable,
) -> Result<String, ContentGenerationError> {
    let mut ret = "[\n".to_string();

    let compiler_flags = target.compiler_flags.join(" ");

    let pwd = Path::new(".");
    let pwd = pwd.canonicalize().unwrap();
    let pwd = pwd.to_str().unwrap();

    if target.sources.len() == 0 {
        return Err(ContentGenerationError {
            message: format!(
                "compile_commands_target is set to `{0}`, however `{0}` has no sources.",
                name
            ),
        });
    }

    for (i, source) in target.sources.iter().enumerate() {
        let new_file = source.replace("/", "-");
        let obj_name = format!("{}/{}/obj/{}.o", config.build_dir, name, new_file);

        ret.push_str(&format!(
            "  {{
    \"directory\": \"{0}\",
    \"command\": \"{1} {2} -o {3} -c {4}\",
    \"file\": \"{4}\"
  }}",
            pwd, target.compiler, compiler_flags, obj_name, source
        ));
        if i != target.sources.len() - 1 {
            ret.push(',');
        }
        ret.push('\n');
    }

    ret.push_str("]\n");

    Ok(ret)
}
