use super::*;
use crate::ngen_toml::*;

#[derive(Debug, Clone)]
pub struct ConfigTable<'a> {
    pub build_dir: &'a str,
    pub compile_commands: bool,
    pub compile_commands_target: &'a str,
}

impl<'a> ConfigTable<'a> {
    pub fn get_default() -> Self {
        ConfigTable {
            build_dir: "build",
            compile_commands: false,
            compile_commands_target: "main",
        }
    }

    pub fn from_parsed_config(
        parsed_config_table: &'a ParsedConfigTable,
    ) -> Result<Self, ConfigurationError> {
        let mut ret = Self::get_default();

        if let Some(v) = &parsed_config_table.build_dir {
            ret.build_dir = v;
        }

        if let Some(v) = &parsed_config_table.compile_commands {
            ret.compile_commands = *v;
        }

        if let Some(v) = &parsed_config_table.compile_commands_target {
            ret.compile_commands_target = v;
        }

        Ok(ret)
    }
}
