use super::*;
use crate::ngen_toml::*;

#[derive(Debug, Clone)]
pub struct TargetOptions<'a> {
    pub inherit: bool,
    pub inherit_from: &'a str,
    pub default: bool,
}

impl<'a> TargetOptions<'a> {
    pub fn get_default() -> Self {
        TargetOptions {
            inherit: true,
            inherit_from: "main",
            default: false,
        }
    }
    pub fn from_parsed_target_options(
        parsed_target_options: &'a ParsedTargetOptions,
    ) -> Result<Self, ConfigurationError> {
        let mut ret = Self::get_default();

        if let Some(v) = &parsed_target_options.inherit {
            ret.inherit = *v;
        }

        if let Some(v) = &parsed_target_options.inherit_from {
            ret.inherit_from = v;
        }

        if let Some(v) = &parsed_target_options.default {
            ret.default = *v;
        }

        Ok(ret)
    }
}
